@@ -76,7 +76,7 @@ public:
 	char	display[MAX_DISPLAY_SIZE];
 	char	remote[MAX_USERID_SIZE];
 	enum {OFFLINE = 0, IDLE, BUSY, AWAY, DND} status;
-	enum {EXPIRED = 0, USER, GATEWAY, SERVICE, REJECT, REFER, TEMPORARY, REGISTRATION} type;
+	enum {EXPIRED = 0, USER, GATEWAY, SERVICE, REJECT, REFER, TEMPORARY, EXTERNAL} type;
 	bool hidden;
 	int rid;					// registry remap or peer id 
 	unsigned ext;				// 0 or extnum
@@ -86,9 +86,17 @@ public:
 	time_t	created;			// initial registration
 	volatile time_t  expires;	// when registry expires as a whole
 	profile_t profile;			// profile at time of registration
-	LinkedObject *published;	// published routes
-	LinkedObject *targets;		// active registrations (can be multiple)
-	LinkedObject *routes;		// active route records
+	union {
+		struct {				// external registry properties...
+			const char *identity;	// forced identity string when calling
+			const char *connect;	// invite uri host identity
+		} external;
+		struct {				// internal registry properties
+			LinkedObject *published;	// published routes
+			LinkedObject *targets;	// active registrations (can be multiple)
+			LinkedObject *routes;	// active route records
+		} internal;
+	};
 };
 
 class __EXPORT MappedCall : public ReusableObject
