@@ -75,13 +75,13 @@ public:
 	static char *receive(void);
 	static void reply(const char *err = NULL);
 	static size_t attach(const char *ident, const char *user);
-	static void util(const char *ident);
 	static void release(void);
 	static bool state(const char *value);
 	static bool system(const char *fmt, ...) __PRINTF(1, 2);
 	static FILE *dumpfile(const char *uid);
 	static FILE *snapshot(const char *uid);
 	static FILE *config(const char *uid = NULL);
+	static void uuid(char *buffer, size_t size, const char *node);
 };
 
 #if defined(DEBUG) || defined(OLD_STDCPP) || defined(NEW_STDCPP)
