@@ -17,10 +17,6 @@
 #include <eXosip2/eXosip.h>
 #include <config.h>
 
-#ifdef	_MSWINDOWS_
-#undef	USES_COMMANDS
-#endif
-
 #ifndef	SESSION_EXPIRES
 #define	SESSION_EXPIRES	"session-expires"
 #endif
@@ -431,7 +427,6 @@ public:
 	static void release(keynode *node);
 	static void release(usernode& user);
 	static void reload(const char *uid);
-	static void utils(const char *uid);
 	static Socket::address *getContact(const char *id);
 	static unsigned forwarding(keynode *node);
 	static void plugins(const char *argv0, const char *names);
@@ -441,13 +436,14 @@ public:
 	static void stop(void);
 	static caddr_t allocate(size_t size, LinkedObject **list, volatile unsigned *count = NULL);
 	static unsigned allocate(void);
-	static void regdump(void);	
 
 	static bool classify(rtpproxy::session *session, rtpproxy::session *source, struct sockaddr *addr);
 	static void activate(MappedRegistry *rr);
 	static void expire(MappedRegistry *rr);
 	static void registration(int id, modules::regmode_t mode);
 	static bool authenticate(int id, const char *realm);
+	static MappedRegistry *redirect(const char *target);
+	static MappedRegistry *accept(const char *request);
 	static const char *referLocal(MappedRegistry *rr, const char *target, char *buffer, size_t size);
 	static const char *referRemote(MappedRegistry *rr, const char *target, char *buffer, size_t size);
 
@@ -503,6 +499,7 @@ private:
 	service::usernode dialed;
 	service::keynode *routed;
 	registry::mapped *reginfo;
+	MappedRegistry *accepted;
 	eXosip_event_t *sevent;
 	char buffer[MAX_URI_SIZE];	
 	char identbuf[MAX_USERID_SIZE + 12];
